jacinle.concurrency.packing
===========================

.. automodule:: jacinle.concurrency.packing

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      check_msgpack
      check_pickle
      check_pyarrow
      dumpb
      get_available_backends
      get_default_backend
      loadb
      set_default_backend
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: check_msgpack

.. autofunction:: check_pickle

.. autofunction:: check_pyarrow

.. autofunction:: dumpb

.. autofunction:: get_available_backends

.. autofunction:: get_default_backend

.. autofunction:: loadb

.. autofunction:: set_default_backend


